kernel::bsp::device_driver::bcm::bcm2xxx_pl011_uart::FR::BUSY

Enum Value

pub enum Value {}
UART busy. If this bit is set to 1, the UART is busy transmitting data. This bit remains set until the complete byte, including all the stop bits, has been sent from the shift register.

This bit is set as soon as the transmit FIFO becomes non-empty, regardless of whether the UART is enabled or not.